@@ -18,8 +18,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-__all__ = ['never', 'VerificationError']
+import operator
 
+__all__ = ['never', 'VerificationError']
 
 class VerificationError(AssertionError):
     '''Indicates error during verification of invocations.
@@ -29,6 +30,9 @@ class VerificationError(AssertionError):
     pass
 
 
+__tracebackhide__ = operator.methodcaller("errisinstance", VerificationError)
+
+
 class AtLeast(object):
     def __init__(self, wanted_count):
         self.wanted_count = wanted_count
@@ -74,10 +78,36 @@ class Times(object):
 
     def verify(self, invocation, actual_count):
         if actual_count == self.wanted_count:
-                return
+            return
+
         if actual_count == 0:
-            raise VerificationError("\nWanted but not invoked: %s"
-                                    % (invocation))
+            invocations = (
+                [
+                    invoc
+                    for invoc in invocation.mock.invocations
+                    if invoc.method_name == invocation.method_name
+                ]
+                or invocation.mock.invocations
+                or ['Nothing']
+            )
+            raise VerificationError(
+                """
+Wanted but not invoked:
+
+    %s
+
+Instead got:
+
+    %s
+
+"""
+                % (
+                    invocation,
+                    "\n    ".join(
+                        str(invoc) for invoc in reversed(invocations)
+                    )
+                )
+            )
         else:
             if self.wanted_count == 0:
                 raise VerificationError(
@@ -110,8 +140,9 @@ class InOrder(object):
             if not invocation.verified_inorder:
                 if not wanted_invocation.matches(invocation):
                     raise VerificationError(
-                        "\nWanted %s to be invoked, got %s instead"
-                        % (wanted_invocation, invocation))
+                        '\nWanted %s to be invoked,'
+                        '\ngot    %s instead.' %
+                        (wanted_invocation, invocation))
                 invocation.verified_inorder = True
                 break
         # proceed with original verification
